/**
 * Setup database for test.
 * @function setupTestDb
 * @param {function} callback - Callback when done.
 */

"use strict";

var sqlite3 = require('sqlite3'),
    path = require('path'),
    async = require('async'),
    fs = require('fs');

var basedir = path.resolve(__dirname, '../..'),
    SETUP_SQL_FILE = path.resolve(basedir, 'ci/assets/setup_test_db.sql');

/** @lends setupTestDb */
function setupTestDb(connectConfig, callback) {
    var Database = sqlite3.verbose().Database;
    var db = new Database(connectConfig);
    async.waterfall([
        function (callback) {
            fs.readFile(SETUP_SQL_FILE, callback);
        },
        function (sql, callback) {
            db.serialize(function () {
                var done = false;
                var queries = String(sql).split(/;/g);
                for (var i = 0; i < queries.length; i++) {
                    var last = queries.length - 1 === i;
                    db.run(queries[i], function (err) {
                        if (err) {
                            callback(err);
                            done = true;
                        }
                    });
                    if (last && !done) {
                        callback(null);
                    }
                }
            });
        }
    ], function (err) {
        db.close(function () {
            if (err) {
                console.error(err);
            }
            callback(err);
        });
    });
}
module.exports = setupTestDb;